@@ -246,14 +246,17 @@ def generate_output(args, semi_result, reference, chrom, temporary_dir):
 
     # genotype_trigger = TriggerGT[args.genotype]
 
+    f=open("%sresults/%s.pickle"%(temporary_dir,chrom), "wb")
     semi_result.sort(key = lambda x:int(x[2]))
     action = args.genotype
     fa_file = pysam.FastaFile(reference)
-    ref_chrom=fa_file.fetch(chrom)
+    try:
+        ref_chrom=fa_file.fetch(chrom)
+    except:
+        raise Exception("No corresponding contig in reference with %s."%(chrom))
     fa_file.close()
     lines=[]
     BATCH_SIZE=1000
-    f=open("%sresults/%s.pickle"%(temporary_dir,chrom), "wb")
     for i in semi_result:
         if i[1] in ["DEL", "INS"]:
             if abs(int(float(i[3]))) > args.max_size and args.max_size != -1:
@@ -422,7 +425,10 @@ def generate_output(args, semi_result, reference, chrom, temporary_dir):
 # def generate_pvcf(args, result, contigINFO, argv, ref_g):
 def generate_pvcf(args, result, reference, chrom):
     fa_file = pysam.FastaFile(reference)
-    ref_chrom=fa_file.fetch(chrom)
+    try:
+        ref_chrom=fa_file.fetch(chrom)
+    except:
+        raise Exception("No corresponding contig in reference with %s."%(chrom))
     fa_file.close()
     # file = open(args.output, 'w')
     # Generation_VCF_header(file, contigINFO, args.sample, argv)
